package application;

import java.io.File;

import javafx.application.Platform;
import javafx.scene.control.Alert.AlertType;
import javafx.scene.control.Menu;
import javafx.scene.control.MenuBar;
import javafx.scene.control.MenuItem;
import javafx.scene.layout.BorderPane;
import javafx.stage.FileChooser;
import model.Getrank;
import model.GetrankException;
import model.Shop;

public class RootBorderPane extends BorderPane
{
	MenuBar menuBar;
	Menu menuDatei;
	MenuItem menuItemLaden, menuItemBeenden;
	Menu menuShop;
	MenuItem menuItemSortPreis, menuItemMaxPreis, menuItemAndern;
	
	private GetrankeUbersicht getrankeUbersicht;
	private Shop shop;
	
	public RootBorderPane()
	{
		initMenu();
		addMenu();
		initComponents();
		addComponents();
		initHandlers();
		enableComponents(false);
	}

	private void initMenu()
	{
		menuBar = new MenuBar();
		menuDatei = new Menu("Datei");
		menuItemLaden = new MenuItem("Laden");
		menuItemBeenden = new MenuItem("Beenden");
		menuShop = new Menu("Shop");
		menuItemSortPreis = new MenuItem("Sort Preis");
		menuItemMaxPreis = new MenuItem("Max Preis");
		menuItemAndern = new MenuItem("Ändern");
	}

	private void addMenu()
	{
		menuDatei.getItems().addAll(menuItemLaden, menuItemBeenden);
		menuShop.getItems().addAll(menuItemSortPreis, menuItemMaxPreis, menuItemAndern);
		menuBar.getMenus().addAll(menuDatei, menuShop);
	}

	private void initComponents()
	{
		shop = new Shop();
		getrankeUbersicht = new GetrankeUbersicht();
	}

	private void addComponents()
	{
		setTop(menuBar);
		setCenter(getrankeUbersicht);
	}
	
	private void enableComponents(boolean enable)
	{
		menuItemSortPreis.setDisable(!enable);
		menuItemMaxPreis.setDisable(!enable);
		menuItemAndern.setDisable(!enable);
		getrankeUbersicht.setVisible(enable);
	}

	private void initHandlers()
	{
		menuItemLaden.setOnAction( event -> laden() );
		menuItemBeenden.setOnAction( event -> Platform.exit() );
		menuItemMaxPreis.setOnAction( event -> maxPreis() );
		menuItemSortPreis.setOnAction( event -> sortPreis() );
		menuItemAndern.setOnAction( event -> andern() );
	}
	
	private void andern()
	{
		Getrank getrank;
		GetrankDialog getrankeDialog;
		
		getrank = getrankeUbersicht.setSingleSelectedLine();
		getrankeDialog = new GetrankDialog();
		getrankeDialog.updateAndShow(getrank);
		getrankeUbersicht.updateUbersicht(shop.getGetranke());
	}
	
	private void sortPreis()
	{
		shop.sortPreis();
		getrankeUbersicht.updateUbersicht(shop.getGetranke());
	}
	
	private void maxPreis()
	{
		double max;
		try
		{
			max = shop.maxPreis();
			Main.showAlert(AlertType.INFORMATION, "Maximaler Preis: " + max);
		}
		catch (GetrankException e)
		{
			Main.showAlert(AlertType.ERROR, e.getMessage());
		}
	}
	
	private void laden()
	{
		FileChooser fileChooser;
		File selected;
		try
		{
			fileChooser = new FileChooser();
			fileChooser.setInitialDirectory(new File("/home/thomas"));
			fileChooser.setTitle("Daten importieren");
			selected = fileChooser.showOpenDialog(null);
			if (selected != null)
			{
				shop.importGetranke(selected.getAbsolutePath());
				getrankeUbersicht.updateUbersicht(shop.getGetranke());
				enableComponents(true);
			}
		}
		catch (GetrankException e)
		{
			Main.showAlert(AlertType.ERROR, e.getMessage());
		}
	}
}





















